Page 116 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 116

Home

    The scoundrels that president Wilson chose to support
    were eventually led by Plutareo Elias Calles. Although
    Calles, known as the Supreme Chief, was for a long time
    the dominate force in the atheistic socialism of Mexico,

    As a primary school teacher, and municipal treasurer
    at Guaymas, he was dismissed for immorality and
    disappearance of funds. He then rose from bartender to

    owner of the Elias hotel, which burned under conditions
    that prevented insurance from carrying the loss. In 1911
    he was police chief of Agua Prieta, and owner of a
    saloon and gambling hall. He made this the only one in
    town by killing his rival and taking his goods. Patronage
    of brothels, and seizure of women, earned him some
    unprintable names.

    Captured in 1912, he was saved from execution by
    Dr. Manuel Huerta whom he later hanged. In 1922 he
    violated United States territory by sending men to kidnap
    and murder General Blanco and Colonel Martinez who

    were refuges in Laredo, Texas. Officials in Laredo were
    prevented from taking legal action against Calles because
    of diplomatic immunity being conferred on him by the
    United States Secretary of State.

    Rising with Obregon into prominence among the
    Carranza-Villa bandits of Sonora, Calles was rewarded

    with the governorship of Sonora and later the presidency
    of Mexico as successor to Obregon.

    111

    Babylon's War Against God

    he was never able to produce his record of birth as a

    citizen of Mexico.